@@ -1,19 +1,19 @@
-package Error::Hierarchy;
-use 5.006;
-use warnings;
+use 5.008;
 use strict;
+use warnings;
+
+package Error::Hierarchy;
+our $VERSION = '1.100850';
+# ABSTRACT: Support for hierarchical exception classes
 use Carp;
 use Data::UUID;
 use Sys::Hostname;
-use base 'Error::Hierarchy::Base';
-our $VERSION = '0.09';
-#<<<
+use parent 'Error::Hierarchy::Base';
 __PACKAGE__
     ->mk_boolean_accessors(qw(is_optional acknowledged))
     ->mk_accessors(qw(
         message exception_hostname package filename line depth stacktrace uuid
     ));
-#>>>
 
 # properties() is used for introspection by code that's catching exceptions.
 # This code can be left generic as each exception class will know its own
@@ -79,14 +79,19 @@ sub comparable {
     $self->stringify;
 }
 1;
+
+
 __END__
-
-
+=pod
 
 =head1 NAME
 
 Error::Hierarchy - Support for hierarchical exception classes
 
+=head1 VERSION
+
+version 1.100850
+
 =head1 SYNOPSIS
 
     package Error::Hierarchy::ReadOnlyAttribute;
@@ -127,9 +132,7 @@ exceptions might define.
 
 =head1 METHODS
 
-=over 4
-
-=item C<depth()>
+=head2 depth
 
 Get or set the caller depth, that is the number of call stack frames that are
 skipped when reporting the package, filename and line the error was thrown
@@ -150,7 +153,7 @@ C<assert_foo()> was called from.
 
 The actual exception depth is influenced by C<error_depth()> as well.
 
-=item C<error_depth()>
+=head2 error_depth
 
 Like C<depth()>, but here the value should be defined within the exception
 class code itself. Therefore, you can't set the value, but subclasses can
@@ -173,21 +176,21 @@ example:
         1 + $self->SUPER::error_depth();
     }
 
-=item C<comparable()>
+=head2 comparable
 
 Support for L<Data::Comparable>.
 
-=item C<init()>
+=head2 init
 
 Initializes a newly constructed exception object.
 
-=item C<get_properties()>
+=head2 get_properties
 
 Actual exception classes will subclass this class and define properties.
 Exception classes themselves can be subclassed. So this method returns the
 inherited list of all the exception class' properties.
 
-=item C<properties_as_hash()>
+=head2 properties_as_hash
 
 Constructs a hash whose keys are the exception's properties - see
 C<get_properties()> - and whose values are the values of each property in the
@@ -197,7 +200,7 @@ omitted.
 In list context, the hash is returned as is. In scalar context, a reference to
 the hash is returned.
 
-=item C<stringify()>
+=head2 stringify
 
 Defines how the exception should look if the object is stringified. This class
 inherits from L<Error::Hierarchy::Base>, which overloads C<""> to call
@@ -206,153 +209,46 @@ C<stringify()>.
 This class stringifies an itself by taking the C<message()> attribute and
 passing it to C<sprintf()>, along with the exception's properties.
 
-=item C<transmute($exception, %args)>
+=head2 transmute($exception, %args)
 
 Transmutes an existing exception. It leaves the stack trace, filename, line
 etc. as it is and just blesses it into the class on which C<transmute()> was
 called, adding the given additional arguments. This is used when catching a
 generic exception and turning it into a more specific one.
 
-=item C<acknowledged>
+=head1 INSTALLATION
 
-    $obj->acknowledged($value);
-    my $value = $obj->acknowledged;
-
-If called without an argument, returns the boolean value (0 or 1). If called
-with an argument, it normalizes it to the boolean value. That is, the values
-0, undef and the empty string become 0; everything else becomes 1.
-
-=item C<acknowledged_clear>
-
-    $obj->acknowledged_clear;
-
-Clears the boolean value by setting it to 0.
-
-=item C<acknowledged_set>
-
-    $obj->acknowledged_set;
-
-Sets the boolean value to 1.
-
-=item C<clear_acknowledged>
-
-    $obj->clear_acknowledged;
-
-Clears the boolean value by setting it to 0.
-
-=item C<clear_is_optional>
-
-    $obj->clear_is_optional;
-
-Clears the boolean value by setting it to 0.
-
-=item C<is_optional>
-
-    $obj->is_optional($value);
-    my $value = $obj->is_optional;
-
-Defines whether the exception is optional or mandatory. This isn't really part
-of the exception itself, it has to do more with how you process the exception.
-You might want to treat some exceptions as more important than others. But
-it's nice to be able to set it within the exception object.
-
-If called without an argument, returns the boolean value (0 or 1). If called
-with an argument, it normalizes it to the boolean value. That is, the values
-0, undef and the empty string become 0; everything else becomes 1.
-
-=item C<is_optional_clear>
-
-    $obj->is_optional_clear;
-
-Clears the boolean value by setting it to 0.
-
-=item C<is_optional_set>
-
-    $obj->is_optional_set;
-
-Sets the boolean value to 1.
-
-=item C<set_acknowledged>
-
-    $obj->set_acknowledged;
-
-Sets the boolean value to 1.
-
-=item C<set_is_optional>
-
-    $obj->set_is_optional;
-
-Sets the boolean value to 1.
-
-=back
-
-Error::Hierarchy inherits from L<Error::Hierarchy::Base>.
-
-The superclass L<Error::Hierarchy::Base> defines these methods and
-functions:
-
-    new(), dump_as_yaml(), dump_raw()
-
-The superclass L<Error> defines these methods and functions:
-
-    _throw_Error_Simple(), associate(), catch(), file(), flush(), import(),
-    object(), prior(), record(), text(), throw(), value(), with()
-
-The superclass L<Data::Inherited> defines these methods and functions:
-
-    every_hash(), every_list(), flush_every_cache_by_key()
-
-The superclass L<Class::Accessor::Complex> defines these methods and
-functions:
-
-    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
-    mk_class_array_accessors(), mk_class_hash_accessors(),
-    mk_class_scalar_accessors(), mk_concat_accessors(),
-    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
-    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
-    mk_set_accessors(), mk_singleton()
-
-The superclass L<Class::Accessor> defines these methods and functions:
-
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
-    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
-
-The superclass L<Class::Accessor::Installer> defines these methods and
-functions:
-
-    install_accessor()
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Error-Hierarchy/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-=head1 AUTHORS
+The development version lives at
+L<http://github.com/hanekomu/Error-Hierarchy/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+=head1 AUTHOR
+
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2004 by Marcel Gruenauer.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
