@@ -1,11 +1,14 @@
-package Error::Hierarchy::Test;
-use warnings;
+use 5.008;
 use strict;
+use warnings;
+
+package Error::Hierarchy::Test;
+our $VERSION = '1.100850';
+# ABSTRACT: Tools to test hierarchical exceptions
 use Test::Builder;
 use Test::Exception;
 use Error ':try';
-our $VERSION = '0.09';
-use base 'Exporter';
+use Exporter qw(import);
 our %EXPORT_TAGS = (misc => [qw{throws2_ok exception_ok}],);
 our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
 my $Tester = Test::Builder->new;
@@ -51,11 +54,18 @@ sub throws2_ok (&$$;$) {
     $ok;
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
-Error::Hierarchy::Test - tools to test hierarchical exceptions
+Error::Hierarchy::Test - Tools to test hierarchical exceptions
+
+=head1 VERSION
+
+version 1.100850
 
 =head1 SYNOPSIS
 
@@ -71,9 +81,7 @@ This module provides some tools that help in testing hierarchical exceptions.
 
 =head1 FUNCTIONS
 
-=over 4
-
-=item C<exception_ok>
+=head2 exception_ok
 
 Takes as arguments in the given order: an exception object, a class name, the
 expected content and optionally a test name.
@@ -92,7 +100,7 @@ If the test name is not given, the stringified exception is used.
 Otherwise it behaves like L<Test::More>'s C<ok()>. If the test was not ok, a
 diagnostic is printed.
 
-=item C<throws2_ok>
+=head2 throws2_ok
 
 Takes as arguments in the given order: A code reference, a class name, the
 expected content and optionally a test name.
@@ -103,36 +111,39 @@ the code threw the given exception, with semantics per C<exception_ok()>.
 Diagnostics are printed if the exception did not match the expectations, or if
 no exception was thrown.
 
-=back
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Error-Hierarchy>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Error-Hierarchy/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Error-Hierarchy/>.
 
-=head1 AUTHORS
+The development version lives at
+L<http://github.com/hanekomu/Error-Hierarchy/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+=head1 AUTHOR
+
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2009 by the authors.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2004 by Marcel Gruenauer.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
